Credits
=======

This package was developed by MPA Solutions

Development Lead
----------------

* Alessandro Regolini <regolini@mpasol.it> 
* Alessio Bazzanella <bazzanella@mpasol.it>
* Radim Blazek <radim.blazek@gmail.com>

Contributors
------------

None yet. Why not be the first?
